body{margin:0;background:#FAFAFA}a{color:#70b0ff;text-decoration:none}body,html{box-sizing:border-box}*,*:before,*:after{font-family:Inter-Display,sans-serif;font-weight:500;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;box-sizing:inherit}:focus{outline:none;box-shadow:0 0 0 2px #afcbeb}.ag-icon,.ag-icon:before,.ag-icon:after,.ag-checkbox-input-wrapper,.ag-checkbox-input-wrapper:before,.ag-checkbox-input-wrapper:after{font-family:agGridAlpine;font-style:normal;font-weight:400;font-variant:normal}
